@@ -86,7 +86,8 @@ report = ""
 trainer = "false"
 azure_variable = "testtorun"
 pipeoutput = "false"
-
+bitrise = "false"
+recursive = "false"
 
 def find(name):
     currentdir = os.getcwd() # using current dir, could change this to work with full computer search
@@ -340,19 +341,22 @@ def runcommand(command, stream="false"):
         return result.stdout.decode('utf-8')
 
 def delete_reports():
-    if reporttype == "directory":
-        folder = report
-        for filename in os.listdir(folder):
-            file_path = os.path.join(folder, filename)
-            try:
-                if os.path.isfile(file_path) or os.path.islink(file_path):
-                    os.unlink(file_path)
-                elif os.path.isdir(file_path):
-                    shutil.rmtree(file_path)
-            except Exception as e:
-                print(('Failed to delete %s. Reason: %s' % (file_path, e)))
-    if reporttype == "file":
-        os.remove(report)
+    try:
+        if reporttype == "directory":
+            folder = report
+            for filename in os.listdir(folder):
+                file_path = os.path.join(folder, filename)
+                try:
+                    if os.path.isfile(file_path) or os.path.islink(file_path):
+                        os.unlink(file_path)
+                    elif os.path.isdir(file_path):
+                        shutil.rmtree(file_path)
+                except Exception as e:
+                    print(('Failed to delete %s. Reason: %s' % (file_path, e)))
+        if reporttype == "file":
+            os.remove(report)
+    except Exception as exp:
+        print(('Failed to delete. Reason: %s' % (exp)))
 
 
 def execute_tests(testlist, testset):
@@ -466,7 +470,7 @@ def get_tests(testpriority):
     print((response.status_code))
 
     if response.status_code >= 500:
-        print(('[!] [{0}] Server Error'.format(response.status_code)))
+        print(('[!] [{0}] Server Error {1}'.format(response.status_code, response.content.decode('utf-8'))))
         return None
     elif response.status_code == 404:
         print(('[!] [{0}] URL not found: [{1}]'.format(response.status_code,api_url)))
@@ -573,7 +577,7 @@ def getresults():
     print("result request sent")
     resultset = ""
     if response.status_code >= 500:
-        print(('[!] [{0}] Server Error'.format(response.status_code)))
+        print(('[!] [{0}] Server Error {1}'.format(response.status_code, response.content.decode('utf-8'))))
         return None
     elif response.status_code == 404:
         print(('[!] [{0}] URL not found: [{1}]'.format(response.status_code,api_url)))
@@ -616,12 +620,21 @@ def push_results():
     
     if reporttype == "directory":
         filetype = ".xml"
-        if importtype == "trx":
-            filetype = ".trx"
-        for file in os.listdir(report):
-            if file.endswith(filetype):
-                echo(file)
-                call_import(os.path.abspath(os.path.join(report, file)))
+        if recursive == "true":
+            if importtype == "trx":
+                filetype = ".trx"
+            for root, dirs, files in os.walk(report):
+                for file in files:
+                    if file.endswith(filetype):
+                        echo(file)
+                        call_import(os.path.abspath(os.path.join(report, file)))
+        if recursive == "false":
+            if importtype == "trx":
+                filetype = ".trx"
+            for file in os.listdir(report):
+                if file.endswith(filetype):
+                    echo(file)
+                    call_import(os.path.abspath(os.path.join(report, file)))
     if reporttype == "file":
         call_import(report)
 
@@ -678,10 +691,10 @@ def call_import(filepath):
 
 def runtestswithappsurify(*args):
     global tests, teststorun, run_id, proxy, username, password, url, apikey, project, testsuite, report, maxtests, fail, additionalargs, testseparator, postfixtest, prefixtest
-    global fullnameseparator, fullname, failfast, maxrerun, rerun, importtype, reporttype, teststorun, deletereports, startrunall, endrunall, startrunspecifi, endrunspecific
+    global fullnameseparator, fullname, failfast, maxrerun, rerun, importtype, reporttype, teststorun, deletereports, startrunall, endrunall, startrunspecific, endrunspecific
     global commit, scriptlocation, branch, runfrequency, fromcommit, repository, scriptlocation, generatefile, template, addtestsuitename, addclassname, runtemplate, testsuitesnameseparator
     global testtemplate, classnameseparator, testseparatorend, testtemplatearg1, testtemplatearg2, testtemplatearg3, testtemplatearg4, startrunpostfix, endrunprefix
-    global endrunpostfix, executetests, encodetests, testsuiteencoded, projectencoded, testsrun, trainer, azure_variable, pipeoutput
+    global endrunpostfix, executetests, encodetests, testsuiteencoded, projectencoded, testsrun, trainer, azure_variable, pipeoutput, recursive, bitrise
 
     tests=""
     testsrun=""
@@ -742,6 +755,8 @@ def runtestswithappsurify(*args):
     trainer = "false"
     azure_variable = "testtorun"
     pipeoutput = "false"
+    bitrise = "false"
+    recursive = "false"
     #--testsuitesnameseparator and classnameseparator need to be encoded i.e. # is %23
 
 
@@ -891,7 +906,7 @@ def runtestswithappsurify(*args):
         startrunall="gradle test"
         report="./build/test-results/"
         reporttype="directory"
-        deletereports="true"
+        deletereports="false"
 
     if testtemplate == "mvn":
         testseparator=","
@@ -902,7 +917,7 @@ def runtestswithappsurify(*args):
         startrunall="mvn test"
         report="./target/surefire-reports/"
         reporttype="directory"
-        deletereports="true"
+        deletereports="false"
 
     if testtemplate == "webdriverio mocha":
         testseparator="|"
@@ -914,6 +929,9 @@ def runtestswithappsurify(*args):
         prefixtest="^"
         startrunall="wdio test "
 
+#protractor - https://stackoverflow.com/questions/24536572/how-to-run-a-single-specific-test-case-when-using-protractor
+#https://github.com/angular/protractor/issues/164
+
 
     #mvn test -Dcucumber.options="--name 'another scenario' --name '^a few cukes$'"
     if testtemplate == "cucmber mvn":
@@ -925,7 +943,7 @@ def runtestswithappsurify(*args):
         startrunall="mvn test"
         report="./target/surefire-reports/"
         reporttype="directory"
-        deletereports="true"
+        deletereports="false"
 
     if testtemplate == "rspec":
         testseparator=" "
@@ -1013,7 +1031,7 @@ def runtestswithappsurify(*args):
     #cypress
     #https://github.com/bahmutov/cypress-select-tests
     #cypress run --reporter junit --reporter-options mochaFile=result.xml
-    if testtemplate == "cyprus":
+    if testtemplate == "cypress":
         testseparator="|"
         reporttype="file"
         report="results.xml"
@@ -1250,6 +1268,10 @@ def runtestswithappsurify(*args):
                 azure_variable = argv[k+1]
             if argv[k] == "--pipeoutput":
                 pipeoutput = "true"
+            if argv[k] == "--bitrise":
+                bitrise = "true"
+            if argv[k] == "--recursive":
+                recursive = "true"
             if argv[k] == "--help":
                 echo("please see url for more details on this script and how to execute your tests with appsurify - https://github.com/Appsurify/AppsurifyCI")
 
@@ -1372,11 +1394,11 @@ def runtestswithappsurify(*args):
 
     ####start loop
     for i in testtypes:
-        print(("testsrun1 = " + testsrun))
+        #print(("testsrun1 = " + testsrun))
         testsrun = get_and_run_tests(i) + testsrun
 
-    print("Tests to run")
-    print(testsrun)
+    #print("Tests to run")
+    #print(testsrun)
 
     #try:
     #    os.environ["TESTSTORUN"] = testsrun
@@ -1403,6 +1425,8 @@ def runtestswithappsurify(*args):
         print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{testsrun}')
     #print("##vso[task.setvariable variable=BuildVersion;]998")
 
+    if bitrise == "true":
+        print (f'envman add --key TESTS_TO_RUN --value \"{testsrun}\"')
 
 
     if failfast == "false" and rerun == "true" and teststorun != "none":
